/*
 * Copyright 2013 Victor Nazarov <asviraspossible@gmail.com>.
 */
package com.github.sviperll;

/**
 *
 * @author Victor Nazarov <asviraspossible@gmail.com>
 */
public class ConfigurableIsomorphism<T, U> implements Isomorphism<T, U> {
    private final Isomorphism<T, U> isomorphism;
    public ConfigurableIsomorphism(Isomorphism<T, U> isomorphism) {
        this.isomorphism = isomorphism;
    }

    @Override
    public U forward(T object) {
        return isomorphism.forward(object);
    }

    @Override
    public T backward(U object) {
        return isomorphism.backward(object);
    }

    public <V> ConfigurableIsomorphism<T, V> composeWith(Isomorphism<U, V> thatIsomorphism) {
        return Isomorphisms.compose(this.isomorphism, thatIsomorphism);
    }

    public ConfigurableIsomorphism<U, T> reversed() {
        return Isomorphisms.reversed(isomorphism);
    }

    public ConfigurableIsomorphism<T, U> passNullThrough() {
        return Isomorphisms.passNullThrough(isomorphism);
    }

    public ConfigurableIsomorphism<T, U> throwOnNull() {
        return Isomorphisms.throwOnNull(isomorphism);
    }

    public ConfigurableFunction<T, U> asForwardFunction() {
        return Isomorphisms.asForwardFunction(isomorphism);
    }

    public ConfigurableFunction<U, T> asBackwardFunction() {
        return Isomorphisms.asBackwardFunction(isomorphism);
    }
}
